@@ -29,8 +29,10 @@
 #include <glib.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
-/* This is between GTK_PRIORITY_RESIZE and GTK_PRIORITY_REDRAW */
-#define META_PRIORITY_RESIZE (G_PRIORITY_HIGH_IDLE + 15)
+/* This is between GTK_PRIORITY_RESIZE (+10) and GTK_PRIORITY_REDRAW (+20) */
+#define META_PRIORITY_RESIZE    (G_PRIORITY_HIGH_IDLE + 15)
+/* lower than GTK_PRIORITY_REDRAW */
+#define META_PRIORITY_COMPOSITE (G_PRIORITY_HIGH_IDLE + 25)
 
 typedef struct _MetaUI MetaUI;
 
@@ -53,12 +55,20 @@ MetaUI* meta_ui_new (Display *xdisplay,
                      Screen  *screen);
 void    meta_ui_free (MetaUI *ui);
 
+void meta_ui_theme_get_frame_borders (MetaUI *ui,
+                                      MetaFrameType      type,
+                                      MetaFrameFlags     flags,
+                                      int               *top_height,
+                                      int               *bottom_height,
+                                      int               *left_width,
+                                      int               *right_width);
 void meta_ui_get_frame_geometry (MetaUI *ui,
                                  Window frame_xwindow,
                                  int *top_height, int *bottom_height,
                                  int *left_width, int *right_width);
 Window meta_ui_create_frame_window (MetaUI *ui,
-				    Display *xdisplay,
+                                    Display *xdisplay,
+                                    Visual *xvisual,
 				    gint x,
 				    gint y,
 				    gint width,
